from .amcache.amcache import AmCachePlugin
from .ntuser.persistence import NTUserPersistencePlugin
from .ntuser.user_assist import UserAssistPlugin
from .system.routes import RoutesPlugin
# Services plugin is currently disabled because it is relatively slow
# from .system.services import ServicesPlugin
from .system.computer_name import ComputerNamePlugin
from .system.shimcache import ShimCachePlugin
from .software.installed_programs import InstalledSoftwarePlugin
from .software.image_file_execution_options import ImageFileExecutionOptions
from .software.persistence import SoftwarePersistencePlugin
from .system.timezone_data import TimezoneDataPlugin
from .system.active_controlset import ActiveControlSetPlugin



from regipy.plugins.plugin import PLUGINS


def run_relevant_plugins(registry_hive, as_json=False, plugins=None):
    """
    Execute the relevant plugins on the hive
    :param registry_hive: a RegistryHive object
    :param as_json: Whether to return result as json
    :param plugins: List of plugin to execute (names according to the NAME field in each plugin)
    :return: The result, as dict
    """
    plugin_results = {}
    for plugin_class in PLUGINS:
        plugin = plugin_class(registry_hive, as_json=as_json)

        # If the list of plugins is defined, but the plugin is not in the list skip it.
        if plugins and not plugin.NAME in plugins:
            continue

        if plugin.can_run():
            plugin_results[plugin.NAME] = plugin.run()
    return plugin_results


